#ifndef MISC_H
#define MISC_H

#include <qpoint.h>
#include <qdir.h>
#include <iostream>

using namespace std;


/////////////////////////////////////////////////////////////////////////////
QString qpointToString (const QPoint &p);
QString qpointfToString (const QPointF &p);
extern ostream &operator<< (ostream &stream, QPoint const &p);
extern ostream &operator<< (ostream &stream, QPointF const &p);
qreal getAngle(const QPointF &);
QPointF normalise (const QPointF &);
QString quotemeta(const QString&);	
qreal max (qreal,qreal);
class BranchObj;
class MapEditor;

/////////////////////////////////////////////////////////////////////////////
class xmlObj
{
public:
    xmlObj();
    QString singleElement(QString,QString);			// name,attr
    QString beginElement(QString,QString);			// name,attr
    QString beginElement(QString);					// name
    QString endElement  (QString);					// name
    QString attribut    (QString,QString);			// name, val
    QString valueElement(QString,QString);			// name, val
    QString valueElement(QString,QString,QString);	// name, attr, val
    void incIndent();
    void decIndent();
    static int actindent;

protected:  
    QString indent();
    int indentwidth;
};

#endif
